/*
 * @author norbert
 * @date 17.03.2006
 * @version $Id: ResolvableDatasourceExample.java,v 1.2 2006-04-11 11:49:28 norbert Exp $
 */
package com.gentics.portalnode.sdk.resolvable;

import java.io.IOException;

import javax.portlet.PortletException;
import javax.portlet.PortletSession;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

import com.gentics.api.lib.datasource.ResolvableDatasource;
import com.gentics.api.portalnode.plugin.GenticsPlugin;
import com.gentics.api.portalnode.plugin.ViewPlugin;
import com.gentics.api.portalnode.portlet.AbstractGenticsPortlet;

/**
 * Example portlet that shows how to create
 * {@link com.gentics.api.lib.datasource.ResolvableDatasource}s and fill them
 * with custom userdata.
 */
public class ResolvableDatasourceExample extends AbstractGenticsPortlet {
    /**
     * name of the datasource
     */
    public final static String DATASOURCE_NAME = "users";

    /**
     * Create an instance of the example portlet
     * @param moduleId portlet id
     * @throws PortletException
     */
    public ResolvableDatasourceExample(String moduleId) throws PortletException {
        super(moduleId);
    }

    /* (non-Javadoc)
     * @see javax.portlet.GenericPortlet#doView(javax.portlet.RenderRequest, javax.portlet.RenderResponse)
     */
    protected void doView(RenderRequest request, RenderResponse response) throws PortletException, IOException {
        PortletSession session = request.getPortletSession();

        if (session.getAttribute(DATASOURCE_NAME) == null) {
            // prepare and fill the resolvable datasource here
            ResolvableDatasource datasource = new ResolvableDatasource();

            // create new objects here. normally the data will come from a
            // custom database or other external source
            UserBean angelina = new UserBean();
            angelina.setFirstName("Angelina");
            angelina.setLastName("Jolie");
            datasource.add(angelina);

            UserBean brad = new UserBean();
            brad.setFirstName("Brad");
            brad.setLastName("Pitt");
            datasource.add(brad);

            // put the datasource into the portlet session, so that it can be
            // accessed by components and pluggable actions
            session.setAttribute(DATASOURCE_NAME, datasource);
        }

        // render the viewplugin
        response.getWriter().print(renderPlugin("viewplugin", request, response));
    }

    /*
     * (non-Javadoc)
     * @see com.gentics.api.portalnode.portlet.AbstractGenticsPortlet#onLoad()
     */
    protected void onLoad() {
        super.onLoad();

        // create a new viewplugin
        GenticsPlugin plugin = getGenticsPortletContext().createPlugin(
                "ViewPlugin", "viewplugin", getPortletConfig());

        // register the plugin
        if (plugin instanceof ViewPlugin) {
            registerPlugin("viewplugin", plugin);
        }
    }
}
